@@ -40,11 +40,12 @@
 ****************************************************************************/
 
 
-#include <QtGui/QtGui>
+#include <QtGui>
 
 #include "modeltest.h"
 
 #include <QtTest/QtTest>
+#include <QVariant>
 #undef Q_ASSERT
 #define Q_ASSERT  QVERIFY
 
@@ -416,27 +417,27 @@ void ModelTest::data()
     // General Purpose roles that should return a QString
     QVariant variant = model->data ( model->index ( 0, 0 ), Qt::ToolTipRole );
     if ( variant.isValid() ) {
-        Q_ASSERT ( qVariantCanConvert<QString> ( variant ) );
+        Q_ASSERT ( variant.canConvert<QString>() );
     }
     variant = model->data ( model->index ( 0, 0 ), Qt::StatusTipRole );
     if ( variant.isValid() ) {
-        Q_ASSERT ( qVariantCanConvert<QString> ( variant ) );
+        Q_ASSERT ( variant.canConvert<QString>() );
     }
     variant = model->data ( model->index ( 0, 0 ), Qt::WhatsThisRole );
     if ( variant.isValid() ) {
-        Q_ASSERT ( qVariantCanConvert<QString> ( variant ) );
+        Q_ASSERT ( variant.canConvert<QString>() );
     }
 
     // General Purpose roles that should return a QSize
     variant = model->data ( model->index ( 0, 0 ), Qt::SizeHintRole );
     if ( variant.isValid() ) {
-        Q_ASSERT ( qVariantCanConvert<QSize> ( variant ) );
+        Q_ASSERT ( variant.canConvert<QSize>() );
     }
 
     // General Purpose roles that should return a QFont
     QVariant fontVariant = model->data ( model->index ( 0, 0 ), Qt::FontRole );
     if ( fontVariant.isValid() ) {
-        Q_ASSERT ( qVariantCanConvert<QFont> ( fontVariant ) );
+        Q_ASSERT ( fontVariant.canConvert<QFont>() );
     }
 
     // Check that the alignment is one we know about
@@ -449,12 +450,12 @@ void ModelTest::data()
     // General Purpose roles that should return a QColor
     QVariant colorVariant = model->data ( model->index ( 0, 0 ), Qt::BackgroundColorRole );
     if ( colorVariant.isValid() ) {
-        Q_ASSERT ( qVariantCanConvert<QColor> ( colorVariant ) );
+        Q_ASSERT ( colorVariant.canConvert<QColor>() );
     }
 
     colorVariant = model->data ( model->index ( 0, 0 ), Qt::TextColorRole );
     if ( colorVariant.isValid() ) {
-        Q_ASSERT ( qVariantCanConvert<QColor> ( colorVariant ) );
+        Q_ASSERT ( colorVariant.canConvert<QColor>() );
     }
 
     // Check that the "check state" is one we know about.
@@ -472,7 +473,7 @@ void ModelTest::data()
 
     \sa rowsInserted()
  */
-void ModelTest::rowsAboutToBeInserted ( const QModelIndex &parent, int start, int end )
+void ModelTest::rowsAboutToBeInserted ( const QModelIndex &parent, int start, int /*end*/ )
 {
 //     Q_UNUSED(end);
 //    qDebug() << "rowsAboutToBeInserted" << "start=" << start << "end=" << end << "parent=" << model->data ( parent ).toString()
