@@ -32,7 +32,7 @@
 #include <resources/AbstractResourcesBackend.h>
 #include "Transaction/AddonList.h"
 
-#include "libmuonprivate_export.h"
+#include "libMuonCommon_export.h"
 
 class KConfigGroup;
 class KNSReviews;
@@ -42,7 +42,7 @@ namespace Attica {
     class BaseJob;
 }
 
-class MUONPRIVATE_EXPORT KNSBackend : public AbstractResourcesBackend
+class MUONCOMMON_EXPORT KNSBackend : public AbstractResourcesBackend
 {
 Q_OBJECT
 public:
@@ -61,6 +61,7 @@ public:
     virtual QVector< AbstractResource* > allResources() const;
     virtual AbstractBackendUpdater* backendUpdater() const;
     virtual bool isFetching() const;
+    virtual QList<QAction*> messageActions() const { return QList<QAction*>(); }
 
     bool isValid() const;
     Attica::Provider* provider() { return &m_provider; }
