@@ -32,6 +32,7 @@
 #include <QDebug>
 #include <QCoreApplication>
 #include <QThread>
+#include <QAction>
 
 // static const KCatalogLoader loader("libmuon");//FIXME port
 
@@ -47,7 +48,7 @@ ResourcesModel *ResourcesModel::global()
 ResourcesModel::ResourcesModel(QObject* parent, bool load)
     : QAbstractListModel(parent)
     , m_initializingBackends(0)
-    , m_mainwindow(0)
+    , m_mainwindow(nullptr)
 {
     init(load);
     connect(this, SIGNAL(allInitialized()), SIGNAL(fetchingChanged()));
@@ -413,3 +414,13 @@ bool ResourcesModel::isFetching() const
     }
     return false;
 }
+
+QList<QAction*> ResourcesModel::messageActions() const
+{
+    QList<QAction*> ret;
+    foreach(AbstractResourcesBackend* b, m_backends) {
+        ret += b->messageActions();
+    }
+    Q_ASSERT(!ret.contains(nullptr));
+    return ret;
+}
