@@ -26,9 +26,11 @@
 #include <QtCore/QPropertyAnimation>
 #include <QtCore/QStringBuilder>
 #include <QtCore/QTextStream>
+#include <QProcess>
 #include <QtWidgets/QToolButton>
 #include <QtWidgets/QVBoxLayout>
 #include <QtWidgets/QApplication>
+#include <QDesktopServices>
 
 // KDE includes
 #include <KIO/Job>
@@ -38,6 +40,8 @@
 #include <KPixmapSequenceOverlayPainter>
 #include <KIconLoader>
 #include <QTextBrowser>
+#include <QPushButton>
+#include <QDebug>
 
 ChangelogWidget::ChangelogWidget(QWidget *parent)
         : QWidget(parent)
@@ -61,9 +65,11 @@ ChangelogWidget::ChangelogWidget(QWidget *parent)
     sideWidget->setLayout(sideLayout);
 
     m_changelogBrowser = new QTextBrowser(this);
+    m_changelogBrowser->setOpenLinks(false);
     m_changelogBrowser->setFrameShape(QFrame::NoFrame);
     m_changelogBrowser->setFrameShadow(QFrame::Plain);
     m_changelogBrowser->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+    connect(m_changelogBrowser, &QTextBrowser::anchorClicked, this, &ChangelogWidget::showMore);
 
     QWidget *viewport = m_changelogBrowser->viewport();
     QPalette palette = viewport->palette();
@@ -77,7 +83,6 @@ ChangelogWidget::ChangelogWidget(QWidget *parent)
     m_busyWidget->setWidget(this);
 
     QHBoxLayout *mainLayout = new QHBoxLayout(this);
-    mainLayout->setMargin(0);
     mainLayout->setSpacing(0);
     mainLayout->addWidget(sideWidget);
     mainLayout->addWidget(m_changelogBrowser);
@@ -144,7 +149,11 @@ void ChangelogWidget::changelogFetched(const QString& changelog)
     if (m_package) {
         // Work around http://bugreports.qt.nokia.com/browse/QTBUG-2533 by forcibly resetting the CharFormat
         m_changelogBrowser->setCurrentCharFormat(QTextCharFormat());
-        m_changelogBrowser->setHtml(changelog);
+        QString fullText;
+        fullText += i18nc("@info/rich", "<p><b>Package Name:</b> <a href='package:%1'>%1</a></p>", m_package->packageName());
+        fullText += i18nc("@info/rich", "<p><b>Installed Version:</b> %1</p>", m_package->installedVersion());
+        fullText += changelog;
+        m_changelogBrowser->setHtml(fullText);
     }
 
     m_busyWidget->stop();
@@ -160,3 +169,15 @@ void ChangelogWidget::fetchChangelog()
     m_busyWidget->start();
     m_package->fetchChangelog();
 }
+
+void ChangelogWidget::showMore(const QUrl& package)
+{
+    if (package.scheme() == QLatin1String("package")) {
+        bool b = QProcess::startDetached("muon-discover", { "--application", package.path() });
+        if (!b) {
+            qWarning() << "Couldn't launch muon-discover";
+        }
+    } else {
+        QDesktopServices::openUrl(package);
+    }
+}
